Update of /cvsroot/sbcl/sbcl/src/compiler/ppc
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv10638/src/compiler/ppc
Modified Files:
array.lisp call.lisp char.lisp move.lisp vm.lisp
Log Message:
0.8.16.9:
Backend renaming of various BASE-CHAR things to CHARACTER things
... BASE-CHAR-REG -> CHARACTER-REG
... BASE-CHAR-STACK -> CHARACTER-STACK
... BASE-CHAR-SC-NUMBER -> CHARACTER-SC-NUMBER
... etc.
... as a somewhat unexpected side effect, the BASE-CHAR class
gets deleted, essentially because of the note containing
"BOGGLE" in src/compiler/generic/primtype.lisp: array
specializations are converted to primitive types by
testing the specifier of the specialization against a list
with EQUAL, and the BASE-CHAR/CHARACTER ambiguity hurts.
Just as in June 2003, this looks too hard to solve right now.
This patch was brought to you by character_branch and M-%
Index: array.lisp
===================================================================
RCS file: /cvsroot/sbcl/sbcl/src/compiler/ppc/array.lisp,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -d -r1.6 -r1.7
--- array.lisp 10 Aug 2004 14:20:48 -0000 1.6
+++ array.lisp 27 Oct 2004 16:40:00 -0000 1.7
@@ -110,7 +110,7 @@
(:results (result :scs ,scs))
(:result-types ,element-type)))))
(def-data-vector-frobs simple-base-string byte-index
- base-char base-char-reg)
+ character character-reg)
(def-data-vector-frobs simple-vector word-index
* descriptor-reg any-reg)
Index: call.lisp
===================================================================
RCS file: /cvsroot/sbcl/sbcl/src/compiler/ppc/call.lisp,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -d -r1.9 -r1.10
--- call.lisp 13 Sep 2004 22:51:39 -0000 1.9
+++ call.lisp 27 Oct 2004 16:40:01 -0000 1.10
@@ -15,7 +15,6 @@
;;; Return a wired TN describing the N'th full call argument passing
;;; location.
-;;;
(!def-vm-support-routine standard-arg-location (n)
(declare (type unsigned-byte n))
(if (< n register-arg-count)
@@ -95,7 +94,6 @@
(vector-push-extend nil
(ir2-component-constants (component-info component))))
(values))
-
;;;; Frame hackery:
@@ -108,7 +106,6 @@
;;; Used for setting up the Old-FP in local call.
-;;;
(define-vop (current-fp)
(:results (val :scs (any-reg)))
(:generator 1
@@ -116,7 +113,6 @@
;;; Used for computing the caller's NFP for use in known-values return. Only
;;; works assuming there is no variable size stuff on the nstack.
-;;;
(define-vop (compute-old-nfp)
(:results (val :scs (any-reg)))
(:vop-var vop)
@@ -125,7 +121,6 @@
(when nfp
(inst addi val nfp (bytes-needed-for-non-descriptor-stack-frame))))))
-
(define-vop (xep-allocate-frame)
(:info start-lab copy-more-arg-follows)
(:ignore copy-more-arg-follows)
@@ -176,7 +171,6 @@
;;; Allocate a partial frame for passing stack arguments in a full call. Nargs
;;; is the number of arguments passed. If no stack arguments are passed, then
;;; we don't have to do anything.
-;;;
(define-vop (allocate-full-call-frame)
(:info nargs)
(:results (res :scs (any-reg)))
@@ -185,7 +179,6 @@
(move res csp-tn)
(inst addi csp-tn csp-tn (* nargs n-word-bytes)))))
-
;;; Emit code needed at the return-point from an unknown-values call
;;; for a fixed number of values. Values is the head of the TN-REF
;;; list for the locations that the values are to be received into.
@@ -343,7 +336,6 @@
;;; Args and Nargs are TNs wired to the named locations. We must
;;; explicitly allocate these TNs, since their lifetimes overlap with the
;;; results Start and Count (also, it's nice to be able to target them).
-;;;
(defun receive-unknown-values (args nargs start count lra-label temp)
(declare (type tn args nargs start count temp))
(let ((variable-values (gen-label))
@@ -375,9 +367,8 @@
(values))
-;;; VOP that can be inherited by unknown values receivers. The main thing this
-;;; handles is allocation of the result temporaries.
-;;;
+;;; VOP that can be inherited by unknown values receivers. The main
+;;; thing this handles is allocation of the result temporaries.
(define-vop (unknown-values-receiver)
(:results
(start :scs (any-reg))
@@ -411,7 +402,6 @@
;;; Note: we can't use normal load-tn allocation for the fixed args, since all
;;; registers may be tied up by the more operand. Instead, we use
;;; MAYBE-LOAD-STACK-TN.
-;;;
(define-vop (call-local)
(:args (fp)
(nfp)
@@ -456,7 +446,6 @@
;;; Note: we can't use normal load-tn allocation for the fixed args, since all
;;; registers may be tied up by the more operand. Instead, we use
;;; MAYBE-LOAD-STACK-TN.
-;;;
(define-vop (multiple-call-local unknown-values-receiver)
(:args (fp)
(nfp)
@@ -499,7 +488,6 @@
;;; Note: we can't use normal load-tn allocation for the fixed args, since all
;;; registers may be tied up by the more operand. Instead, we use
;;; MAYBE-LOAD-STACK-TN.
-;;;
(define-vop (known-call-local)
(:args (fp)
(nfp)
@@ -539,7 +527,6 @@
;;; Note: we can't use normal load-tn allocation for the fixed args, since all
;;; registers may be tied up by the more operand. Instead, we use
;;; MAYBE-LOAD-STACK-TN.
-;;;
(define-vop (known-return)
(:args (old-fp :target old-fp-temp)
(return-pc :target return-pc-temp)
@@ -825,9 +812,8 @@
(define-full-call multiple-call-variable nil :unknown t)
-;;; Defined separately, since needs special code that BLT's the arguments
-;;; down.
-;;;
+;;; Defined separately, since needs special code that BLT's the
+;;; arguments down.
(define-vop (tail-call-variable)
(:args
(args-arg :scs (any-reg) :target args)
@@ -865,9 +851,7 @@
;;;; Unknown values return:
-
;;; Return a single value using the unknown-values convention.
-;;;
(define-vop (return-single)
(:args (old-fp :scs (any-reg))
(return-pc :scs (descriptor-reg))
@@ -902,7 +886,6 @@
;;; When there are stack values, we must initialize the argument pointer to
;;; point to the beginning of the values block (which is the beginning of the
;;; current frame.)
-;;;
(define-vop (return)
(:args
(old-fp :scs (any-reg))
@@ -948,11 +931,11 @@
(lisp-return return-pc lip)))
(trace-table-entry trace-table-normal)))
-;;; Do unknown-values return of an arbitrary number of values (passed on the
-;;; stack.) We check for the common case of a single return value, and do that
-;;; inline using the normal single value return convention. Otherwise, we
-;;; branch off to code that calls an assembly-routine.
-;;;
+;;; Do unknown-values return of an arbitrary number of values (passed
+;;; on the stack.) We check for the common case of a single return
+;;; value, and do that inline using the normal single value return
+;;; convention. Otherwise, we branch off to code that calls an
+;;; assembly-routine.
(define-vop (return-multiple)
(:args
(old-fp-arg :scs (any-reg) :to (:eval 1))
@@ -998,14 +981,10 @@
(move nvals nvals-arg)
(inst ba (make-fixup 'return-multiple :assembly-routine)))
(trace-table-entry trace-table-normal)))
-
-
;;;; XEP hackery:
-
;;; We don't need to do anything special for regular functions.
-;;;
(define-vop (setup-environment)
(:info label)
(:ignore label)
@@ -1014,7 +993,6 @@
))
;;; Get the lexical environment from its passing location.
-;;;
(define-vop (setup-closure-environment)
(:temporary (:sc descriptor-reg :offset lexenv-offset :target closure
:to (:result 0))
@@ -1028,7 +1006,6 @@
;;; Copy a more arg from the argument area to the end of the current frame.
;;; Fixed is the number of non-more arguments.
-;;;
(define-vop (copy-more-arg)
(:temporary (:sc any-reg :offset nl0-offset) result)
(:temporary (:sc any-reg :offset nl1-offset) count)
@@ -1087,16 +1064,14 @@
(emit-label done))))
-;;; More args are stored consecutively on the stack, starting immediately at
-;;; the context pointer. The context pointer is not typed, so the lowtag is 0.
-;;;
+;;; More args are stored consecutively on the stack, starting
+;;; immediately at the context pointer. The context pointer is not
+;;; typed, so the lowtag is 0.
(define-vop (more-arg word-index-ref)
(:variant 0 0)
(:translate %more-arg))
-
;;; Turn more arg (context, count) into a list.
-;;;
(define-vop (listify-rest-args)
(:args (context-arg :target context :scs (descriptor-reg))
(count-arg :target count :scs (any-reg)))
@@ -1151,16 +1126,16 @@
DONE))
-;;; Return the location and size of the more arg glob created by Copy-More-Arg.
-;;; Supplied is the total number of arguments supplied (originally passed in
-;;; NARGS.) Fixed is the number of non-rest arguments.
-;;;
-;;; We must duplicate some of the work done by Copy-More-Arg, since at that
-;;; time the environment is in a pretty brain-damaged state, preventing this
-;;; info from being returned as values. What we do is compute
-;;; supplied - fixed, and return a pointer that many words below the current
-;;; stack top.
+;;; Return the location and size of the more arg glob created by
+;;; COPY-MORE-ARG. SUPPLIED is the total number of arguments supplied
+;;; (originally passed in NARGS.) Fixed is the number of non-rest
+;;; arguments.
;;;
+;;; We must duplicate some of the work done by COPY-MORE-ARG, since at
+;;; that time the environment is in a pretty brain-damaged state,
+;;; preventing this info from being returned as values. What we do is
+;;; compute (- SUPPLIED FIXED), and return a pointer that many words
+;;; below the current stack top.
(define-vop (more-arg-context)
(:policy :fast-safe)
(:translate sb!c::%more-arg-context)
@@ -1175,24 +1150,6 @@
(inst subi count supplied (fixnumize fixed))
(inst sub context csp-tn count)))
-
-;;; Signal wrong argument count error if Nargs isn't = to Count.
-;;;
-#|
-(define-vop (verify-argument-count)
- (:policy :fast-safe)
- (:translate sb!c::%verify-argument-count)
- (:args (nargs :scs (any-reg)))
- (:arg-types positive-fixnum (:constant t))
- (:info count)
- (:vop-var vop)
- (:save-p :compute-only)
- (:generator 3
- (let ((err-lab
- (generate-error-code vop invalid-argument-count-error nargs)))
- (inst cmpwi nargs (fixnumize count))
- (inst bne err-lab))))
-|#
(define-vop (verify-arg-count)
(:policy :fast-safe)
(:translate sb!c::%verify-arg-count)
@@ -1204,9 +1161,7 @@
(:generator 3
(inst twi :ne nargs (fixnumize count))))
-
;;; Signal various errors.
-;;;
(macrolet ((frob (name error translate &rest args)
`(define-vop (,name)
,@(when translate
Index: move.lisp
===================================================================
RCS file: /cvsroot/sbcl/sbcl/src/compiler/ppc/move.lisp,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -d -r1.2 -r1.3
--- move.lisp 29 Oct 2003 06:38:40 -0000 1.2
+++ move.lisp 27 Oct 2004 16:40:01 -0000 1.3
@@ -1,8 +1,15 @@
-;;; Written by Rob MacLachlan.
-;;; SPARC conversion by William Lott.
-;;;
-(in-package "SB!VM")
+;;;; the PPC VM definition of operand loading/saving and the Move VOP
+
+;;;; This software is part of the SBCL system. See the README file for
+;;;; more information.
+;;;;
+;;;; This software is derived from the CMU CL system, which was
+;;;; written at Carnegie Mellon University and released into the
+;;;; public domain. The software is in the public domain and is
+;;;; provided with absolutely no warranty. See the COPYING and CREDITS
+;;;; files for more information.
+(in-package "SB!VM")
(define-move-fun (load-immediate 1) (vop x y)
((null immediate zero)
@@ -17,15 +24,15 @@
(load-symbol y val))
(character
(inst lr y (logior (ash (char-code val) n-widetag-bits)
- base-char-widetag))))))
+ character-widetag))))))
(define-move-fun (load-number 1) (vop x y)
((immediate zero)
(signed-reg unsigned-reg))
(inst lr y (tn-value x)))
-(define-move-fun (load-base-char 1) (vop x y)
- ((immediate) (base-char-reg))
+(define-move-fun (load-character 1) (vop x y)
+ ((immediate) (character-reg))
(inst li y (char-code (tn-value x))))
(define-move-fun (load-system-area-pointer 1) (vop x y)
@@ -41,7 +48,7 @@
(load-stack-tn y x))
(define-move-fun (load-number-stack 5) (vop x y)
- ((base-char-stack) (base-char-reg)
+ ((character-stack) (character-reg)
(sap-stack) (sap-reg)
(signed-stack) (signed-reg)
(unsigned-stack) (unsigned-reg))
@@ -53,7 +60,7 @@
(store-stack-tn y x))
(define-move-fun (store-number-stack 5) (vop x y)
- ((base-char-reg) (base-char-stack)
+ ((character-reg) (character-stack)
(sap-reg) (sap-stack)
(signed-reg) (signed-stack)
(unsigned-reg) (unsigned-stack))
@@ -62,7 +69,6 @@
;;;; The Move VOP:
-;;;
(define-vop (move)
(:args (x :target y
:scs (any-reg descriptor-reg zero null)
@@ -78,15 +84,13 @@
(any-reg descriptor-reg)
(any-reg descriptor-reg))
-;;; Make Move the check VOP for T so that type check generation doesn't think
-;;; it is a hairy type. This also allows checking of a few of the values in a
-;;; continuation to fall out.
-;;;
+;;; Make MOVE the check VOP for T so that type check generation
+;;; doesn't think it is a hairy type. This also allows checking of a
+;;; few of the values in a continuation to fall out.
(primitive-type-vop move (:check) t)
-;;; The Move-Argument VOP is used for moving descriptor values into another
+;;; The MOVE-ARG VOP is used for moving descriptor values into another
;;; frame for argument or known value passing.
-;;;
(define-vop (move-arg)
(:args (x :target y
:scs (any-reg descriptor-reg zero null))
@@ -108,11 +112,10 @@
;;;; ILLEGAL-MOVE
-;;; This VOP exists just to begin the lifetime of a TN that couldn't be written
-;;; legally due to a type error. An error is signalled before this VOP is
-;;; so we don't need to do anything (not that there would be anything sensible
-;;; to do anyway.)
-;;;
+;;; This VOP exists just to begin the lifetime of a TN that couldn't
+;;; be written legally due to a type error. An error is signalled
+;;; before this VOP is so we don't need to do anything (not that there
+;;; would be anything sensible to do anyway.)
(define-vop (illegal-move)
(:args (x) (type))
(:results (y))
@@ -130,9 +133,8 @@
;;; representation. Similarly, the MOVE-FROM-WORD VOPs converts a raw integer
;;; to a tagged bignum or fixnum.
-;;; Arg is a fixnum, so just shift it. We need a type restriction because some
+;;; ARG is a fixnum, so just shift it. We need a type restriction because some
;;; possible arg SCs (control-stack) overlap with possible bignum arg SCs.
-;;;
(define-vop (move-to-word/fixnum)
(:args (x :scs (any-reg descriptor-reg)))
(:results (y :scs (signed-reg unsigned-reg)))
@@ -140,23 +142,20 @@
(:note "fixnum untagging")
(:generator 1
(inst srawi y x 2)))
-;;;
(define-move-vop move-to-word/fixnum :move
(any-reg descriptor-reg) (signed-reg unsigned-reg))
-;;; Arg is a non-immediate constant, load it.
+;;; ARG is a non-immediate constant; load it.
(define-vop (move-to-word-c)
(:args (x :scs (constant)))
(:results (y :scs (signed-reg unsigned-reg)))
(:note "constant load")
(:generator 1
(inst lr y (tn-value x))))
-;;;
(define-move-vop move-to-word-c :move
(constant) (signed-reg unsigned-reg))
-
-;;; Arg is a fixnum or bignum, figure out which and load if necessary.
+;;; ARG is a fixnum or bignum; figure out which and load if necessary.
(define-vop (move-to-word/integer)
(:args (x :scs (descriptor-reg)))
(:results (y :scs (signed-reg unsigned-reg)))
@@ -175,15 +174,11 @@
(loadw y x bignum-digits-offset other-pointer-lowtag)
(emit-label done))))
-;;;
(define-move-vop move-to-word/integer :move
(descriptor-reg) (signed-reg unsigned-reg))
-
-
-;;; Result is a fixnum, so we can just shift. We need the result type
+;;; RESULT is a fixnum, so we can just shift. We need the result type
;;; restriction because of the control-stack ambiguity noted above.
-;;;
(define-vop (move-from-word/fixnum)
(:args (x :scs (signed-reg unsigned-reg)))
(:results (y :scs (any-reg descriptor-reg)))
@@ -191,14 +186,11 @@
(:note "fixnum tagging")
(:generator 1
(inst slwi y x 2)))
-;;;
(define-move-vop move-from-word/fixnum :move
(signed-reg unsigned-reg) (any-reg descriptor-reg))
-
-;;; Result may be a bignum, so we have to check. Use a worst-case cost to make
-;;; sure people know they may be number consing.
-;;;
+;;; RESULT may be a bignum, so we have to check. Use a worst-case
+;;; cost to make sure people know they may be number consing.
(define-vop (move-from-signed)
(:args (arg :scs (signed-reg unsigned-reg) :target x))
(:results (y :scs (any-reg descriptor-reg)))
@@ -217,14 +209,12 @@
(with-fixed-allocation (y pa-flag temp bignum-widetag (1+ bignum-digits-offset))
(storew x y bignum-digits-offset other-pointer-lowtag))
(emit-label done))))
-;;;
(define-move-vop move-from-signed :move
(signed-reg) (descriptor-reg))
-
-;;; Check for fixnum, and possibly allocate one or two word bignum result. Use
-;;; a worst-case cost to make sure people know they may be number consing.
-;;;
+;;; Check for fixnum, and possibly allocate one or two word bignum
+;;; result. Use a worst-case cost to make sure people know they may
+;;; be number consing.
(define-vop (move-from-unsigned)
(:args (arg :scs (signed-reg unsigned-reg) :target x))
(:results (y :scs (any-reg descriptor-reg)))
@@ -253,13 +243,11 @@
(storew temp y 0 other-pointer-lowtag)
(storew x y bignum-digits-offset other-pointer-lowtag))
(emit-label done))))
-;;;
(define-move-vop move-from-unsigned :move
(unsigned-reg) (descriptor-reg))
;;; Move untagged numbers.
-;;;
(define-vop (word-move)
(:args (x :target y
:scs (signed-reg unsigned-reg)
@@ -271,13 +259,11 @@
(:note "word integer move")
(:generator 0
(move y x)))
-;;;
(define-move-vop word-move :move
(signed-reg unsigned-reg) (signed-reg unsigned-reg))
;;; Move untagged number arguments/return-values.
-;;;
(define-vop (move-word-arg)
(:args (x :target y
:scs (signed-reg unsigned-reg))
@@ -291,13 +277,10 @@
(move y x))
((signed-stack unsigned-stack)
(storew x fp (tn-offset y))))))
-;;;
(define-move-vop move-word-arg :move-arg
(descriptor-reg any-reg signed-reg unsigned-reg) (signed-reg unsigned-reg))
-
-;;; Use standard MOVE-ARGUMENT + coercion to move an untagged number to a
+;;; Use standard MOVE-ARG + coercion to move an untagged number to a
;;; descriptor passing location.
-;;;
(define-move-vop move-arg :move-arg
(signed-reg unsigned-reg) (any-reg descriptor-reg))
Index: vm.lisp
===================================================================
RCS file: /cvsroot/sbcl/sbcl/src/compiler/ppc/vm.lisp,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -d -r1.7 -r1.8
--- vm.lisp 7 Aug 2004 12:20:10 -0000 1.7
+++ vm.lisp 27 Oct 2004 16:40:01 -0000 1.8
@@ -141,7 +141,7 @@
;; The non-descriptor stacks.
(signed-stack non-descriptor-stack) ; (signed-byte 32)
(unsigned-stack non-descriptor-stack) ; (unsigned-byte 32)
- (base-char-stack non-descriptor-stack) ; non-descriptor characters.
+ (character-stack non-descriptor-stack) ; non-descriptor characters.
(sap-stack non-descriptor-stack) ; System area pointers.
(single-stack non-descriptor-stack) ; single-floats
(double-stack non-descriptor-stack
@@ -169,11 +169,11 @@
:alternate-scs (control-stack))
;; Non-Descriptor characters
- (base-char-reg registers
+ (character-reg registers
:locations #.non-descriptor-regs
:constant-scs (immediate)
:save-p t
- :alternate-scs (base-char-stack))
+ :alternate-scs (character-stack))
;; Non-Descriptor SAP's (arbitrary pointers into address space)
(sap-reg registers
|
Index: char.lisp
===================================================================
RCS file: /cvsroot/sbcl/sbcl/src/compiler/ppc/char.lisp,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -d -r1.3 -r1.4
--- char.lisp 10 Nov 2003 23:26:38 -0000 1.3
+++ char.lisp 27 Oct 2004 16:40:01 -0000 1.4
@@ -14,78 +14,70 @@
;;;; Moves and coercions:
;;; Move a tagged char to an untagged representation.
-(define-vop (move-to-base-char)
+(define-vop (move-to-character)
(:args (x :scs (any-reg descriptor-reg)))
- (:results (y :scs (base-char-reg)))
+ (:results (y :scs (character-reg)))
(:note "character untagging")
(:generator 1
(inst srwi y x n-widetag-bits)))
-
-(define-move-vop move-to-base-char :move
- (any-reg descriptor-reg) (base-char-reg))
-
+(define-move-vop move-to-character :move
+ (any-reg descriptor-reg) (character-reg))
;;; Move an untagged char to a tagged representation.
-(define-vop (move-from-base-char)
- (:args (x :scs (base-char-reg)))
+(define-vop (move-from-character)
+ (:args (x :scs (character-reg)))
(:results (y :scs (any-reg descriptor-reg)))
(:note "character tagging")
(:generator 1
(inst slwi y x n-widetag-bits)
- (inst ori y y base-char-widetag)))
-
-(define-move-vop move-from-base-char :move
- (base-char-reg) (any-reg descriptor-reg))
+ (inst ori y y character-widetag)))
+(define-move-vop move-from-character :move
+ (character-reg) (any-reg descriptor-reg))
-;;; Move untagged base-char values.
-(define-vop (base-char-move)
+;;; Move untagged character values.
+(define-vop (character-move)
(:args (x :target y
- :scs (base-char-reg)
+ :scs (character-reg)
:load-if (not (location= x y))))
- (:results (y :scs (base-char-reg)
+ (:results (y :scs (character-reg)
:load-if (not (location= x y))))
(:note "character move")
(:effects)
(:affected)
(:generator 0
(move y x)))
+(define-move-vop character-move :move
+ (character-reg) (character-reg))
-(define-move-vop base-char-move :move
- (base-char-reg) (base-char-reg))
-
-;;; Move untagged base-char arguments/return-values.
-(define-vop (move-base-char-arg)
+;;; Move untagged character arguments/return-values.
+(define-vop (move-character-arg)
(:args (x :target y
- :scs (base-char-reg))
+ :scs (character-reg))
(fp :scs (any-reg)
- :load-if (not (sc-is y base-char-reg))))
+ :load-if (not (sc-is y character-reg))))
(:results (y))
(:note "character arg move")
(:generator 0
(sc-case y
- (base-char-reg
+ (character-reg
(move y x))
- (base-char-stack
+ (character-stack
(storew x fp (tn-offset y))))))
+(define-move-vop move-character-arg :move-arg
+ (any-reg character-reg) (character-reg))
-(define-move-vop move-base-char-arg :move-arg
- (any-reg base-char-reg) (base-char-reg))
-
-
-;;; Use standard MOVE-ARG + coercion to move an untagged base-char
+;;; Use standard MOVE-ARG + coercion to move an untagged character
;;; to a descriptor passing location.
(define-move-vop move-arg :move-arg
- (base-char-reg) (any-reg descriptor-reg))
-
-
+ (character-reg) (any-reg descriptor-reg))
;;;; Other operations:
(define-vop (char-code)
(:translate char-code)
(:policy :fast-safe)
- (:args (ch :scs (base-char-reg) :target res))
- (:arg-types base-char)
+ (:args (ch :scs (character-reg) :target res))
+ (:arg-types character)
(:results (res :scs (any-reg)))
(:result-types positive-fixnum)
(:generator 1
@@ -96,17 +88,16 @@
(:policy :fast-safe)
(:args (code :scs (any-reg) :target res))
(:arg-types positive-fixnum)
- (:results (res :scs (base-char-reg)))
- (:result-types base-char)
+ (:results (res :scs (character-reg)))
+ (:result-types character)
(:generator 1
(inst srwi res code 2)))
-
-;;; Comparison of base-chars.
-(define-vop (base-char-compare)
- (:args (x :scs (base-char-reg))
- (y :scs (base-char-reg)))
- (:arg-types base-char base-char)
+;;; Comparison of characters.
+(define-vop (character-compare)
+ (:args (x :scs (character-reg))
+ (y :scs (character-reg)))
+ (:arg-types character character)
(:conditional)
(:info target not-p)
(:policy :fast-safe)
@@ -116,21 +107,21 @@
(inst cmplw x y)
(inst b? (if not-p not-condition condition) target)))
-(define-vop (fast-char=/base-char base-char-compare)
+(define-vop (fast-char=/character character-compare)
(:translate char=)
(:variant :eq :ne))
-(define-vop (fast-char</base-char base-char-compare)
+(define-vop (fast-char</character character-compare)
(:translate char<)
(:variant :lt :ge))
-(define-vop (fast-char>/base-char base-char-compare)
+(define-vop (fast-char>/character character-compare)
(:translate char>)
(:variant :gt :le))
-(define-vop (base-char-compare/c)
- (:args (x :scs (base-char-reg)))
- (:arg-types base-char (:constant base-char))
+(define-vop (character-compare/c)
+ (:args (x :scs (character-reg)))
+ (:arg-types character (:constant character))
(:conditional)
(:info target not-p y)
(:policy :fast-safe)
@@ -140,15 +131,14 @@
(inst cmplwi x (sb!xc:char-code y))
(inst b? (if not-p not-condition condition) target)))
-(define-vop (fast-char=/base-char/c base-char-compare/c)
+(define-vop (fast-char=/character/c character-compare/c)
(:translate char=)
(:variant :eq :ne))
-(define-vop (fast-char</base-char/c base-char-compare/c)
+(define-vop (fast-char</character/c character-compare/c)
(:translate char<)
(:variant :lt :ge))
-(define-vop (fast-char>/base-char/c base-char-compare/c)
+(define-vop (fast-char>/character/c character-compare/c)
(:translate char>)
(:variant :gt :le))
-